@@ -14,9 +14,9 @@ def getDict(dictionary,*keys,**kwargs):
 	if "default" in kwargs:
 		rtn = kwargs["default"]
 	for key in keys:
-		if key in dic:
+		try:
 			dic = dic[key]
-		else:
+		except:
 			return rtn
 	
 	return dic
@@ -25,18 +25,20 @@ def getDict(dictionary,*keys,**kwargs):
 
 if __name__ == '__main__':
 	from IutyLib.coding.asserts import *
+	import sys
+	sys.path.insert(0,"../../")
 	a = {'a':11,'b':{"b0":112,"b1":"ascii"}}
 	i0 = getDict(a,"a")
 	assertEqual(i0,11)
 
-	i1 = getDict("b","b0")
+	i1 = getDict(a,"b","b0")
 	assertEqual(i1,112)
 
-	i3 = getDict("b","b1",1)
+	i3 = getDict(a,"b","b1",1)
 	assertEqual(i3,'s')
 
-	i4 = getDict("c")
+	i4 = getDict(a,"c")
 	assertEqual(i4,None)
 
-	i5 = getDict("c",default="no data")
+	i5 = getDict(a,"c",default="no data")
 	assertEqual(i5,"no data")
